@@ -83,13 +83,9 @@ describe 'glance::backend::multistore::rbd' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
-          if facts[:operatingsystem] == 'Debian'
-            { :pyceph_package_name => 'python3-ceph' }
-          else
-            { :pyceph_package_name => 'python3-rbd' }
-          end
+          { :pyceph_package_name => 'python3-ceph' }
         when 'RedHat'
           { :pyceph_package_name => 'python3-rbd' }
         end
